# Catalog

CERULEo dataset catalog is a collection of RUL estimation datasets ready to use. All datasets are exposed as `AbstractTimeSeriesDataset`, enabling easy-to-use and transformation input pipelines. To get started see the guide and our list of datasets.

* [`CMAPSS`][ceruleo.dataset.catalog.CMAPSS.CMAPSSDataset]
* [`CMPSS-2`][ceruleo.dataset.catalog.CMAPSS2.CMAPSS2Dataset]
* [`PHM Dataset 2018`][ceruleo.dataset.catalog.PHMDataset2018.PHMDataset2018]

## CMAPSS

::: ceruleo.dataset.catalog.CMAPSS

## CMAPSS-2

::: ceruleo.dataset.catalog.CMAPSS2

## PHMDataset2018

::: ceruleo.dataset.catalog.PHMDataset2018


